==> scriptedforms-0.7.1.tar.gz: scriptedforms-0.7.1/scriptedforms/src/app/variables-module/variables.module.ts <==
// Scripted Forms -- Making GUIs easy for everyone on your team.
// Copyright (C) 2017 Simon Biggs

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published
// by the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version (the "AGPL-3.0+").

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License and the additional terms for more
// details.

// You should have received a copy of the GNU Affero General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

// ADDITIONAL TERMS are also included as allowed by Section 7 of the GNU
// Affrero General Public License. These aditional terms are Sections 1, 5,
// 6, 7, 8, and 9 from the Apache License, Version 2.0 (the "Apache-2.0")
// where all references to the definition "License" are instead defined to
// mean the AGPL-3.0+.

// You should have received a copy of the Apache-2.0 along with this
// program. If not, see <http://www.apache.org/licenses/LICENSE-2.0>.
/*
A module containing the form elements.
*/

import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

import {
  MaterialModule
} from '../../vendors/material.module';

import { ToggleComponent } from './toggle.component';
import { TickComponent } from './tick.component';
import { ConditionalComponent } from './conditional.component';

import { NumberComponent } from './number.component';
import { SliderComponent } from './slider.component';
import { TableComponent } from './table.component';

import { StringComponent } from './string.component';
import { DropdownComponent } from './dropdown.component';
import { StringListParameterComponent } from './string-list-parameter.component'


@NgModule({
  imports: [
    CommonModule,
    MaterialModule,
    FormsModule
  ],
  declarations: [
    ToggleComponent,
    TickComponent,
    ConditionalComponent,
    NumberComponent,
    SliderComponent,
    TableComponent,
    StringComponent,
    DropdownComponent,
    StringListParameterComponent
  ],
  exports: [
    ToggleComponent,
    TickComponent,
    ConditionalComponent,
    NumberComponent,
    SliderComponent,
    TableComponent,
    StringComponent,
    DropdownComponent,
    StringListParameterComponent
  ]
})
export class VariablesModule { }

==> scriptedforms-0.8.0.dev3.tar.gz: scriptedforms-0.8.0.dev3/scriptedforms/src/app/variables-module/variables.module.ts <==
// Scripted Forms -- Making GUIs easy for everyone on your team.
// Copyright (C) 2017 Simon Biggs

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published
// by the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version (the "AGPL-3.0+").

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License and the additional terms for more
// details.

// You should have received a copy of the GNU Affero General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

// ADDITIONAL TERMS are also included as allowed by Section 7 of the GNU
// Affrero General Public License. These aditional terms are Sections 1, 5,
// 6, 7, 8, and 9 from the Apache License, Version 2.0 (the "Apache-2.0")
// where all references to the definition "License" are instead defined to
// mean the AGPL-3.0+.

// You should have received a copy of the Apache-2.0 along with this
// program. If not, see <http://www.apache.org/licenses/LICENSE-2.0>.
/*
A module containing the form elements.
*/

import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

import {
  MaterialModule
} from '../../vendors/material.module';

import { VariableBaseComponent } from './variable-base.component';
import { NumberBaseComponent } from './number-base.component';
import { BooleanBaseComponent } from './boolean-base.component';

import { ToggleComponent } from './toggle.component';
import { TickComponent } from './tick.component';
import { ConditionalComponent } from './conditional.component';

import { NumberComponent } from './number.component';
import { SliderComponent } from './slider.component';
import { VariableTableComponent } from './variable-table.component';

import { StringComponent } from './string.component';
import { DropdownComponent } from './dropdown.component';
import { VariableParameterComponent } from './variable-parameter.component';


@NgModule({
  imports: [
    CommonModule,
    MaterialModule,
    FormsModule
  ],
  declarations: [
    VariableBaseComponent,
    NumberBaseComponent,
    BooleanBaseComponent,
    ToggleComponent,
    TickComponent,
    ConditionalComponent,
    NumberComponent,
    SliderComponent,
    VariableTableComponent,
    StringComponent,
    DropdownComponent,
    VariableParameterComponent
  ],
  exports: [
    ToggleComponent,
    TickComponent,
    ConditionalComponent,
    NumberComponent,
    SliderComponent,
    VariableTableComponent,
    StringComponent,
    DropdownComponent,
    VariableParameterComponent
  ]
})
export class VariablesModule { }
